aboutsummaryrefslogtreecommitdiffstats
path: root/resources/tools/presentation/generator_tables.py
diff options
context:
space:
mode:
Diffstat (limited to 'resources/tools/presentation/generator_tables.py')
-rw-r--r--resources/tools/presentation/generator_tables.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/resources/tools/presentation/generator_tables.py b/resources/tools/presentation/generator_tables.py
index 71ec431e6a..58d3b67b55 100644
--- a/resources/tools/presentation/generator_tables.py
+++ b/resources/tools/presentation/generator_tables.py
@@ -335,8 +335,8 @@ def _read_csv_template(file_name):
raise PresentationError(str(err), level="ERROR")
-def table_performance_comparision(table, input_data):
- """Generate the table(s) with algorithm: table_performance_comparision
+def table_performance_comparison(table, input_data):
+ """Generate the table(s) with algorithm: table_performance_comparison
specified in the specification file.
:param table: Table to generate.